aboutsummaryrefslogtreecommitdiffstats
path: root/tools/gpgconf.h
diff options
context:
space:
mode:
Diffstat (limited to 'tools/gpgconf.h')
-rw-r--r--tools/gpgconf.h14
1 files changed, 8 insertions, 6 deletions
diff --git a/tools/gpgconf.h b/tools/gpgconf.h
index 6ccc0d1dd..138380b6d 100644
--- a/tools/gpgconf.h
+++ b/tools/gpgconf.h
@@ -23,12 +23,14 @@
#include "../common/util.h"
-/* We keep all global options in the structure OPT. */
-struct {
- int verbose; /* Verbosity level. */
- int quiet; /* Be extra quiet. */
- int dry_run; /* Don't change any persistent data. */
- char *outfile; /* Name of output file. */
+/* We keep all global options in the structure OPT. */
+struct
+{
+ int verbose; /* Verbosity level. */
+ int quiet; /* Be extra quiet. */
+ int dry_run; /* Don't change any persistent data. */
+ int runtime; /* Make changes active at runtime. */
+ char *outfile; /* Name of output file. */
int component; /* The active component. */
} opt;